@@ -11,6 +11,6 @@
 #' head(x$facet_pivot$`nameWInd,vernacular`)
 #' }
 itis_facet <- function(...) {
-  invisible(solrium::solr_connect(url = "http://services.itis.gov"))
+  invisible(solrium::solr_connect(url = itis_solr_url()))
   solrium::solr_facet(...)
 }
