@@ -8,6 +8,6 @@
 #' head(x)
 #' }
 itis_group <- function(...) {
-  invisible(solrium::solr_connect(url = "http://services.itis.gov"))
+  invisible(solrium::solr_connect(url = itis_solr_url()))
   solrium::solr_group(...)
 }
